@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.2.1'
+VERSION = '0.2.2'
 
 import os
 import sys
@@ -34,6 +34,7 @@ def get_args():
     parser.add_argument(
         '-n', '--new-revision',
         dest='new_revision',
+        type=str,
         default=None,
         help='Kernel revision to create',
     )
@@ -46,6 +47,7 @@ def get_args():
     parser.add_argument(
         '-r', '--config-revision',
         dest='config_revision',
+        type=str,
         default='current',
         help='Config revision to work from',
     )
@@ -175,6 +177,7 @@ class Kernel(object):
             raise
 
     @require_attr('version')
+    @require_attr('revision')
     @require_attr('config_version')
     @require_attr('config_revision')
     def configure(self, merge_method='oldconfig'):
@@ -196,6 +199,13 @@ class Kernel(object):
                 ),
                 '.config'
             )
+        done = False
+        for line in fileinput.input('.config', inplace=True):
+            if not done and line.find('CONFIG_LOCALVERSION') == 0:
+                print('CONFIG_LOCALVERSION="_{0}"'.format(self.revision))
+                done = True
+            else:
+                print(line.rstrip())
         if self.config_version != self.version:
             subprocess.call(['make', merge_method])
 
@@ -203,13 +213,6 @@ class Kernel(object):
     @require_attr('revision')
     def modify(self):
         os.chdir('{0}/sources/linux-{1}'.format(self.root_dir, self.version))
-        done = False
-        for line in fileinput.input('.config', inplace=True):
-            if not done and 'CONFIG_LOCALVERSION' in line:
-                print('CONFIG_LOCALVERSION=_{0}'.format(self.revision))
-                done = True
-            else:
-                print(line.rstrip())
         subprocess.call(['make', 'menuconfig'])
         shutil.copy(
             '.config',
